# Kylin Intrusion Detector

## Overview

### Product introduction
&emsp;&emsp;Intrusion Detection Tool is a lightweight host intrusion detection system that provides simple and efficient threat detection and security assurance. Stand-alone deployment has low system resource occupation.

### Product Highlights
- &nbsp;&nbsp;It can analyze key system logs in real time, regularly scan processes and ports every day, remind users after identifying security risks, and support automatic blocking of malicious IPs.
- &nbsp;&nbsp;Detection capabilities include, but are not limited to, port scanning, brute-force attacks, abnormal logins, privilege escalation attempts, rootkits (hidden processes or ports), SQL injection, XSS, and other common web attacks.
- &nbsp;&nbsp;You can access the alarm content of antivirus software such as CLAM-AV, SYMANTEC-AV, and Sophos, as well as traffic analysis software such as Snort and Suricata.

## Getting started

### Software location
&emsp;&emsp;Click the Start Menu of the operating system, select and click Intrusion Detection Tool, and open the software interface of the Intrusion Detection Tool, as shown in the following figure 1.

![Figure 1 Start menu (Open Kylin Intrusion Detector)-big](image/1.png)

&emsp;&emsp;Click the Start Menu, then Settings, and then Security to display the Security Center homepage. After clicking the "Firewall & Network Protection" button, you can open the software interface through the "Intrusion Detection Tool" option, as shown in the following figure 2.

![Figure 2 Settings (Open Kylin Intrusion Detector)-big](image/2.png)

### Get help
&emsp;&emsp;Click the "Help" button on the menu icon in the upper right corner of the application interface of the Intrusion Detection Tool, and the "User Manual" pop-up window will pop up, displaying the information about the help manual, as shown in Figure 3.

![Figure 3 User Manual-big](image/3.png)

### Mode support
&emsp;&emsp;The display mode of the software interface of the intrusion detection tool changes with the system theme, and the mode can be switched by the theme in the Start Menu -> Settings -> Personalization, as shown in Figure 4 to 5.

![Figure 4 Light Mode-big](image/4.png)

![Figure 5 Dark Mode-big](image/5.png)

### Language support
&emsp;&emsp;The intrusion detection tool software interface follows the system language setting by default and supports Chinese Simplified, Chinese Traditional, English, Tibetan, and Mongolian, as shown in Figure 6 to 10.

![Figure 6 Chinese Simplified Chinese display-big](image/6.png)

![Figure 7 Chinese Traditional Chinese display-big](image/7.png)

![Figure 8 English display-big](image/8.png)

![Figure 9 Tibetan display-big](image/9.png)

![Figure 10 Mongolian display-big](image/10.png)

## Alert log
&emsp;&emsp;When the background service detects a risk event that threatens system security, it will send a desktop alarm notification and save the record. Open the desktop application to view the saved alarm logs, as shown in Figure 11.

![Figure 11 Alarm log (there are alarm events)-big](image/11.png)

**Note**: The higher the level, the greater the risk. The scale 12-14 interval is defined here as average risk, marked in blue; The grade 15-16 range is defined as high risk, marked in red.

&emsp;&emsp;You can use the View Details button on the desktop alarm notification to automatically jump to the Alarm Log page of the desktop app, highlight the corresponding content, and automatically expand more information (manually click the arrow button on the right to expand or collapse).

&emsp;&emsp;Figure 12 is used for desktop alarm notifications, and Figure 13 is shown for highlighted alarm logs.

![Figure 12 Desktop alarm notifications-big](image/12.png)

![Figure 13 Alarm logs are highlighted-big](image/13.png)

&emsp;&emsp;"Reload" is for scenarios where new alarm data appears in the background during the opening of the app, and all data including updated data will be loaded after clicking.

&emsp;&emsp;Date filtering, which is used to filter data within a specified time range.

## Alert Statistics
&emsp;&emsp;Displays the summary information of the detection and classifies the alarm logs.

&emsp;&emsp;If there is an alarm event, the display page is long, and the slider is displayed from top to bottom: Alarm statistics summary (as shown in Figure 14) and alarm statistics details (as shown in Figure 15 to 17).
- &nbsp;&nbsp;Alarm statistics summary;
- &nbsp;&nbsp;Alarm statistics details: alarm level statistics, alarm level date distribution, alarm severity number distribution, event statistics, attack source statistics, and (attacked) user statistics. This section provides date filtering to filter the data within a specified time range;
- &nbsp;&nbsp;Export statistical report and refresh: "Export statistical report" can generate the statistical information report displayed on the current interface. Refresh updates the data of the detection summary and alarm statistics;

![Figure 14 Summary of alarm statistics-big](image/14.png)

![Figure 15 Alarm Level Statistics Details - Date distribution of alarm severity-big](image/15.png)

![Figure 16 Alarm Level Statistics - Distribution of the number of alarm severities-big](image/16.png)

![Figure 17 Alarm Level Statistics Details - Events, Attack Sources, and User Statistics-big](image/17.png)

## Settings
&emsp;&emsp;After clicking the "Settings" button, the settings page will pop up, including "Basic Settings", "Defense Measures", and "AI Network Threat Detection". After the configuration of each page entry is modified, the actual configuration update is performed by clicking the "Confirm" button on the page.

&emsp;&emsp;In the Basic Settings, the Intrusion Detection Service is the core module, which is responsible for monitoring and analyzing whether the system is facing intrusion risks. If this service is disabled, neither of the Defenses and AI Network Threat Detection services will be effective because the Defense Service requires the Intrusion Detection Service to provide them with defense action indicators
The output of the AI network threat detection service will be summarized to the intrusion detection service, and the intrusion detection service will perform operations such as alarm and defense in a unified manner. Therefore, when the Intrusion Detection Service is disabled, the Defense Service and the AI Network Threat Detection Service are disabled simultaneously.

&emsp;&emsp;After desktop notifications are disabled, the alarm notification in the upper right corner of the desktop is no longer generated, which can avoid interference to users, but does not affect the background operation of the service, and new alarm events will still be recorded when system risks are discovered.
![Figure 18 Settings - Basic settings-big](image/18.png)

&emsp;&emsp;The defense service is disabled by default to prevent remote access from being banned due to false positives. If you want to enable this and are worried that some fixed IP addresses will be blocked by mistake, you can add these IP addresses to the IP blocking whitelist and separate them with commas.
![Figure 19 Settings - Defensive measures-big](image/19.png)

&emsp;&emsp;The AI Threat Detection page may be grayed out (neither "On" nor "Off", and the "Cancel" and "Confirm" buttons are not clickable) because the required AI Detection package has not yet been installed.
![Figure 20 Settings - AI Cyber Threat Detection (AI Detection Package Not Installed)-big](image/20.png)

&emsp;&emsp;If the software package "kguard-net-ai" already exists in the system, the AI Network Threat Detection page is operational.
![Figure 21 Settings - AI Cyber Threat Detection (AI Detection Package Installation)-big](image/21.png)

## Appendix: Frequently Asked Questions and Solutions (FAQ)

#### 一、 Alert log
- &nbsp;&nbsp;Why is there nothing under the Alarm Log?

&emsp;&emsp;Answer: No alarm logs are available, which means that the intrusion detection service has not discovered any behavior events that threaten system security.

#### 二、Alert statistics
- &nbsp;&nbsp;How is the "Total Intrusion Detection Protection" duration calculated?

&emsp;&emsp;Answer: The cumulative duration from the time when the package kguard is installed on the system to the current system time.
- &nbsp;&nbsp;What does "Total Log Events" mean?

&emsp;&emsp;Answer: The total number of log rows that have been read for all log files in the monitoring range since the Intrusion Detection Service was launched.

- &nbsp;&nbsp;Why do I see an increase in the Total Log Events every few seconds when I click Refresh?

&emsp;&emsp;Answer: Because each application may frequently write to the system log during the operation of the system, and the "Intrusion Detection Service" is reading and analyzing these log contents simultaneously, the total number of read log rows will continue to increase.
- &nbsp;&nbsp;Why is there only 12~16 alarm levels, but there are no other levels?

&emsp;&emsp;Answer: The rule set contains a large number of rules smaller than level 12, but they are the basic rules that match the top on the chain and do not represent system risk, so with 12 as the boundary, hit rules below this level will not form an alarm event. While level 16 is the highest level defined, there is no level higher than 16.

#### 三、Settings
- &nbsp;&nbsp;What is the effect of "Desktop Notification Folding"?

&emsp;&emsp;Answer: If multiple notifications appear in a short period of time, only the latest alarm notifications are displayed, and the number of notifications after them is displayed.

- &nbsp;&nbsp;IP Blocking Whitelist" sometimes can't be entered.

&emsp;&emsp;Answer: There is data verification in this input box, and the IPs can only be separated by English commas, and the IP number field needs to be between 0~255, and other characters are invalid.

- &nbsp;&nbsp;How does the Defense Service work? What's the difference with a firewall?

&emsp;&emsp;Answer: Receive the defense action command from the Intrusion Detection Service, and then execute the predefined command or script as root. For "IP blocking", the NFT firewall command-line tool blocks the specified IP address and automatically revokes the blocking after the configured duration is exceeded.
